==> humhub-1.8.1.tar.gz: humhub-1.8.1/protected/humhub/modules/admin/messages/pt-BR/user.php <==
<?php
return array (
  '<strong>Information</strong>' => '<strong>Informação</strong>',
  '<strong>Profile</strong> Permissions' => '',
  '<strong>Settings</strong> and Configuration' => '<strong>Definições</strong> e Configuração',
  '<strong>User</strong> administration' => 'Administração de <strong>Usuário</strong>',
  '<strong>Warning:</strong> All individual profile permission settings are reset to the default values!' => '',
  'Accept user: <strong>{displayName}</strong> ' => 'Aceitar usuário: <strong>{displayName}</strong>',
  'Account' => 'Conta',
  'Account Request for \'{displayName}\' has been approved.' => 'Pedido de cadastro de \'{displayName}\' foi recusado.',
  'Account Request for \'{displayName}\' has been declined.' => 'Pedido de cadastro de \'{displayName}\' foi recusado.',
  'Actions' => 'Ações',
  'Active users' => 'Usuários ativos',
  'Add Groups...' => 'Adicionar Grupos...',
  'Add a separate page for the group to the directory.' => '',
  'Add new category' => 'Adicionar nova categoria',
  'Add new field' => 'Adicionar novo campo',
  'Add new group' => 'Adicionar novo grupo',
  'Add new members...' => 'Adicionar novos membros...',
  'Add new user' => 'Adicionar novo usuário',
  'Administrator group could not be deleted!' => '',
  'All open registration invitations were successfully deleted.' => '',
  'All the personal data of this user will be irrevocably deleted.' => 'Todos os dados pessoais deste usuário serão irrevogavelmente excluídos.',
  'Allow' => 'Permitir',
  'Allow users to set individual permissions for their own profile?' => '',
  'Allow visitors limited access to content without an account (Adds visibility: "Guest")' => 'Permitir acesso limitado para usuários não autenticados (convidados)',
  'Applied to new or existing users without any other group membership.' => '',
  'Are you really sure that you want to disable this user?' => 'Tem certeza de que deseja desabilitar esse usuário?',
  'Are you really sure that you want to enable this user?' => 'Você tem certeza de que deseja habilitar esse usuário?',
  'Are you really sure that you want to impersonate this user?' => 'Você tem certeza de que deseja se passar por esse usuário?',
  'Are you really sure? Users who are not assigned to another group are automatically assigned to the default group.' => '',
  'Are you sure that you want to delete following user?' => 'Tem certeza de que deseja excluir o seguinte usuário?',
  'Cancel' => 'Cancelar',
  'Click here to review' => 'Clique aqui para rever',
  'Confirm user deletion' => 'Confirmar exclusão de usuário',
  'Could not load category.' => 'Não foi possível carregar a categoria.',
  'Create new group' => 'Criar novo grupo',
  'Create new profile category' => 'Criar nova categoria de perfil',
  'Create new profile field' => 'Criar novo campo de perfil',
  'Deactivate' => '',
  'Deactivate individual profile permissions?' => '',
  'Decline & delete user: <strong>{displayName}</strong>' => 'Recusar e apagar o usuário: <strong>{displayName}</strong>',
  'Default' => 'Padrão',
  'Default Profile Permissions' => '',
  'Default content of the registration approval email' => 'Conteúdo padrão do e-mail de aprovação de registro',
  'Default content of the registration denial email' => 'Conteúdo padrão do e-mail de negação de registro',
  'Default groups can not be deleted!' => '',
  'Default user idle timeout, auto-logout (in seconds, optional)' => 'Tempo padrão de ócio para logout (em segundos, opcional)',
  'Default user profile visibility' => 'Visibilidade padrão do perfil do usuário',
  'Delete' => 'Apagar',
  'Delete All' => '',
  'Delete all contributions of this user' => 'Excluir todas as contribuições deste usuário',
  'Delete invitation' => 'Excluir convite',
  'Delete invitation?' => 'Excluir convite?',
  'Delete spaces which are owned by this user' => 'Excluir espaços pertencentes a esse usuário',
  'Deleted invitation' => 'Convite excluído',
  'Deleted users' => 'Usuários excluídos',
  'Disable' => 'Desabilitar',
  'Disabled' => 'Desabilitado',
  'Disabled users' => 'Usuários desabilitados',
  'Do not change placeholders like {displayName} if you want them to be automatically filled by the system. To reset the email content fields with the system default, leave them empty.' => 'Não altere espaços reservados como {displayName} se você quer que eles sejam automaticamente preenchidos pelo sistema. Para redefinir o conteúdo de campos de e-mail para o padrão do sistema, deixe-os em branco.',
  'Edit category' => 'Editar categoria',
  'Edit profile category' => 'Editar categoria de perfil',
  'Edit profile field' => 'Editar campo de perfil',
  'Edit user: {name}' => 'Editar usuário: {name}',
  'Enable' => 'Habilitar',
  'Enable individual profile permissions' => '',
  'Enabled' => 'Habilitado',
  'Group Manager' => 'Gerente do Grupo',
  'Group not found!' => 'Grupo não encontrado!',
  'Group user not found!' => 'Usuário de Grupo não encontrado!',
  'Groups' => 'Grupos',
  'Hello {displayName},<br><br>
Your account has been activated.<br><br>
Click here to login:<br>
{loginLink}<br><br>

Kind Regards<br>
{AdminName}<br><br>' => '',
  'Hello {displayName},<br><br>
Your account request has been declined.<br><br>

Kind Regards<br>
{AdminName} <br><br> ' => '',
  'Here you can create or edit profile categories and fields.' => 'Aqui você pode criar ou editar categorias e campo de perfil.',
  'If individual profile permissions are not allowed, the following settings are unchangeable for all users. If individual profile permissions are allowed, the settings are only set as defaults that users can customise. The following entries are then displayed in the same form in the users profile settings:' => '',
  'If this option is not selected, the ownership of the spaces will be transferred to your account.' => 'Se esta opção não estiver selecionada, a propriedade dos espaços será transferida para sua conta.',
  'Impersonate' => 'Representar',
  'Include captcha in registration form' => 'Incluir captcha no formulário de registro',
  'Invite not found!' => 'Convite não encontrado!',
  'Last login' => 'Último acesso',
  'List pending registrations' => 'Listar registros pendentes',
  'Make the group selectable at registration.' => '',
  'Manage group: {groupName}' => 'Gerenciar grupo: {groupName}',
  'Manage groups' => 'Gerenciar grupos',
  'Manage profile attributes' => 'Gerenciar atributos de perfil',
  'Member since' => 'Membro desde',
  'Members' => 'Membros',
  'Members can invite external users by email' => 'Membros podem convidar usuários externos por e-mail',
  'Message' => 'Mensagem',
  'Min value is 20 seconds. If not set, session will timeout after 1400 seconds (24 minutes) regardless of activity (default session timeout)' => 'Valor mínimo é de 20 segundos. Se não for definido, a sessão será interrompida após 1400 segundos (24 minutos), independentemente da atividade (tempo limite de sessão padrão)',
  'New approval requests' => 'Novas solicitações de aprovação',
  'New users can register' => 'Usuários anônimos podem se registrar',
  'No' => 'Não',
  'No value found!' => 'Nenhum valor encontrado!',
  'One or more user needs your approval as group admin.' => 'Um ou mais usuários necessitam da sua aprovação como administrador de grupo.',
  'Only applicable when limited access for non-authenticated users is enabled. Only affects new users.' => 'Apenas aplicável quando o acesso limitado para usuários não-autenticados está habilitado. Afeta apenas novos usuários.',
  'Overview' => 'Visão Global',
  'Password' => 'Senha',
  'Pending approvals' => 'Aprovações pendentes',
  'Pending user approvals' => 'Aprovações de usuários pendentes',
  'Permanently delete' => 'Excluir permanentemente',
  'Permissions' => 'Permissões',
  'Profile Permissions' => '',
  'Profiles' => 'Perfis',
  'Remove from group' => 'Remover do grupo',
  'Require group admin approval after registration' => 'Exigir aprovação do grupo de administração após o registro',
  'Resend invitation email' => 'Reenvie o email de convite',
  'Save' => 'Salvar',
  'Search by name, email or id.' => 'Pesquise por nome, email ou id.',
  'Select Groups' => 'Selecionar Grupos',
  'Send & save' => 'Enviar e salvar',
  'Send invitation email' => 'Enviar email de convite',
  'Send invitation email again?' => 'Enviar email de convite novamente?',
  'Send invite' => 'Enviar convite',
  'Send notifications to users when added to or removed from the group.' => '',
  'Settings' => 'Configurações',
  'Show group selection at registration' => '',
  'Subject' => 'Assunto',
  'The Space memberships of all group members will be updated. This may take up to several minutes.' => '',
  'The following list contains all pending sign-ups and invites.' => 'A lista a seguir contem todos os cadastros e convites pendentes.',
  'The following list contains all registered users awaiting an approval.' => 'A lista a seguir contém todos os usuários registrados que aguardam uma aprovação.',
  'The selected invitations have been successfully deleted!' => '',
  'The user is the owner of these spaces:' => 'O usuário é o proprietário desses espaços:',
  'This option allows you to determine whether users may set individual permissions for their own profiles.' => '',
  'This overview contains a list of each registered user with actions to view, edit and delete users.' => 'Esta visão geral contém uma lista de cada usuário registrado com ações para visualizar, editar e excluir usuários.',
  'This user owns no spaces.' => 'Este usuário não possui espaços.',
  'Unapproved' => 'Não aprovado',
  'User deletion process queued.' => 'Processo de exclusão do usuário enfileirado.',
  'User is already a member of this group.' => 'Usuário já é um membro desse grupo.',
  'User not found!' => 'Usuário não encontrado!',
  'Users' => 'Usuários',
  'Users can be assigned to different groups (e.g. teams, departments etc.) with specific standard spaces, group managers and permissions.' => 'Os usuários podem pertencer a diferentes grupos (p. ex. equipes, departamentos etc.) com normas específicas de espaço, gerentes de grupo e permissões.',
  'Using this option any contributions (e.g. contents, comments or likes) of this user will be irrevocably deleted.' => 'Usando essa opção, quaisquer contribuições (por exemplo, conteúdo, comentários ou curtidas) desse usuário serão irrevogavelmente excluídas.',
  'View profile' => 'Ver perfil',
  'Visible for members only' => 'Visível apenas para membros',
  'Visible for members+guests' => 'Vísivel para membros e visitantes',
  'Yes' => 'Sim',
  'You can only delete empty categories!' => 'Você só pode apagar categorias vazias!',
  'You cannot delete yourself!' => 'Você não pode se deletar!',
  'never' => 'nunca',
);

==> humhub-1.10.2.tar.gz: humhub-1.10.2/protected/humhub/modules/admin/messages/pt-BR/user.php <==
<?php
return array (
  '<strong>Information</strong>' => '<strong>Informação</strong>',
  '<strong>Profile</strong> Permissions' => '<strong>Perfil</strong> Permissões',
  '<strong>Settings</strong> and Configuration' => '<strong>Definições</strong> e Configuração',
  '<strong>User</strong> administration' => 'Administração de <strong>Usuário</strong>',
  '<strong>Warning:</strong> All individual profile permission settings are reset to the default values!' => '<strong>Aviso:</strong> Todas as configurações de permissão de perfil individual são redefinidas para os valores padrão!',
  'Accept user: <strong>{displayName}</strong> ' => 'Aceitar usuário: <strong>{displayName}</strong>',
  'Account' => 'Conta',
  'Account Request for \'{displayName}\' has been approved.' => 'Pedido de cadastro de \'{displayName}\' foi recusado.',
  'Account Request for \'{displayName}\' has been declined.' => 'Pedido de cadastro de \'{displayName}\' foi recusado.',
  'Actions' => 'Ações',
  'Active users' => 'Usuários ativos',
  'Add Groups...' => 'Adicionar Grupos...',
  'Add new category' => 'Adicionar nova categoria',
  'Add new field' => 'Adicionar novo campo',
  'Add new group' => 'Adicionar novo grupo',
  'Add new members...' => 'Adicionar novos membros...',
  'Add new user' => 'Adicionar novo usuário',
  'Administrator group could not be deleted!' => 'Não foi possível deletar o grupo de administradores!',
  'All open registration invitations were successfully deleted.' => 'Todos os convites de inscrição abertos foram excluídos com sucesso.',
  'All the personal data of this user will be irrevocably deleted.' => 'Todos os dados pessoais deste usuário serão irrevogavelmente excluídos.',
  'Allow' => 'Permitir',
  'Allow users to block each other' => '',
  'Allow users to set individual permissions for their own profile?' => 'Permitir que os usuários definam permissões individuais para seus próprios perfis?',
  'Allow visitors limited access to content without an account (Adds visibility: "Guest")' => 'Permitir acesso limitado para usuários não autenticados (convidados)',
  'Applied to new or existing users without any other group membership.' => 'Aplicado a usuários novos ou existentes sem qualquer outra associação de grupo.',
  'Are you really sure that you want to disable this user?' => 'Tem certeza de que deseja desabilitar esse usuário?',
  'Are you really sure that you want to enable this user?' => 'Você tem certeza de que deseja habilitar esse usuário?',
  'Are you really sure that you want to impersonate this user?' => 'Você tem certeza de que deseja se passar por esse usuário?',
  'Are you really sure? Users who are not assigned to another group are automatically assigned to the default group.' => 'Tem certeza mesmo? Os usuários que não estão atribuídos a outro grupo são atribuídos automaticamente ao grupo padrão.',
  'Are you sure that you want to delete following user?' => 'Tem certeza de que deseja excluir o seguinte usuário?',
  'Cancel' => 'Cancelar',
  'Click here to review' => 'Clique aqui para rever',
  'Confirm user deletion' => 'Confirmar exclusão de usuário',
  'Could not load category.' => 'Não foi possível carregar a categoria.',
  'Create new group' => 'Criar novo grupo',
  'Create new profile category' => 'Criar nova categoria de perfil',
  'Create new profile field' => 'Criar novo campo de perfil',
  'Deactivate' => 'Desativar',
  'Deactivate individual profile permissions?' => 'Desativar permissões de perfis individuais?',
  'Decline & delete user: <strong>{displayName}</strong>' => 'Recusar e apagar o usuário: <strong>{displayName}</strong>',
  'Default' => 'Padrão',
  'Default Profile Permissions' => 'Permissões de perfil padrão',
  'Default Sorting' => '',
  'Default content of the registration approval email' => 'Conteúdo padrão do e-mail de aprovação de registro',
  'Default content of the registration denial email' => 'Conteúdo padrão do e-mail de negação de registro',
  'Default group can not be deleted!' => '',
  'Default user idle timeout, auto-logout (in seconds, optional)' => 'Tempo padrão de ócio para logout (em segundos, opcional)',
  'Default user profile visibility' => 'Visibilidade padrão do perfil do usuário',
  'Delete' => 'Apagar',
  'Delete All' => 'Apagar tudo',
  'Delete all contributions of this user' => 'Excluir todas as contribuições deste usuário',
  'Delete invitation' => 'Excluir convite',
  'Delete invitation?' => 'Excluir convite?',
  'Delete spaces which are owned by this user' => 'Excluir espaços pertencentes a esse usuário',
  'Deleted invitation' => 'Convite excluído',
  'Deleted users' => 'Usuários excluídos',
  'Disable' => 'Desabilitar',
  'Disabled' => 'Desabilitado',
  'Disabled users' => 'Usuários desabilitados',
  'Do not change placeholders like {displayName} if you want them to be automatically filled by the system. To reset the email content fields with the system default, leave them empty.' => 'Não altere espaços reservados como {displayName} se você quer que eles sejam automaticamente preenchidos pelo sistema. Para redefinir o conteúdo de campos de e-mail para o padrão do sistema, deixe-os em branco.',
  'Edit category' => 'Editar categoria',
  'Edit profile category' => 'Editar categoria de perfil',
  'Edit profile field' => 'Editar campo de perfil',
  'Edit user: {name}' => 'Editar usuário: {name}',
  'Enable' => 'Habilitar',
  'Enable individual profile permissions' => 'Ativar permissões de perfil individual',
  'Enabled' => 'Habilitado',
  'First name' => 'Primeiro nome',
  'Group Manager' => 'Gerente do Grupo',
  'Group not found!' => 'Grupo não encontrado!',
  'Group user not found!' => 'Usuário de Grupo não encontrado!',
  'Groups' => 'Grupos',
  'Hello {displayName},

Your account has been activated.

Click here to login:
{loginUrl}

Kind Regards
{AdminName}

' => '',
  'Hello {displayName},

Your account request has been declined.

Kind Regards
{AdminName}

' => '',
  'Here you can create or edit profile categories and fields.' => 'Aqui você pode criar ou editar categorias e campo de perfil.',
  'If individual profile permissions are not allowed, the following settings are unchangeable for all users. If individual profile permissions are allowed, the settings are only set as defaults that users can customise. The following entries are then displayed in the same form in the users profile settings:' => 'Se as permissões de perfil individual não forem permitidas, as configurações a seguir não podem ser alteradas para todos os usuários. Se as permissões de perfil individual forem permitidas, as configurações serão definidas apenas como padrões que os usuários podem personalizar. As seguintes entradas são exibidas da mesma forma nas configurações do perfil do usuário:',
  'If this option is not selected, the ownership of the spaces will be transferred to your account.' => 'Se esta opção não estiver selecionada, a propriedade dos espaços será transferida para sua conta.',
  'Impersonate' => 'Representar',
  'Include captcha in registration form' => 'Incluir captcha no formulário de registro',
  'Information 1' => '',
  'Information 2' => '',
  'Information 3' => '',
  'Invite not found!' => 'Convite não encontrado!',
  'Last login' => 'Último acesso',
  'Last name' => 'Último nome',
  'List pending registrations' => 'Listar registros pendentes',
  'Make the group selectable at registration.' => 'Torne o grupo selecionável no momento do registro.',
  'Manage group: {groupName}' => 'Gerenciar grupo: {groupName}',
  'Manage groups' => 'Gerenciar grupos',
  'Manage profile attributes' => 'Gerenciar atributos de perfil',
  'Member since' => 'Membro desde',
  'Members' => 'Membros',
  'Members can invite external users by email' => 'Membros podem convidar usuários externos por e-mail',
  'Message' => 'Mensagem',
  'Min value is 20 seconds. If not set, session will timeout after 1400 seconds (24 minutes) regardless of activity (default session timeout)' => 'Valor mínimo é de 20 segundos. Se não for definido, a sessão será interrompida após 1400 segundos (24 minutos), independentemente da atividade (tempo limite de sessão padrão)',
  'New approval requests' => 'Novas solicitações de aprovação',
  'New users can register' => 'Usuários anônimos podem se registrar',
  'No' => 'Não',
  'No value found!' => 'Nenhum valor encontrado!',
  'None' => 'Nenhum',
  'Not visible' => '',
  'One or more user needs your approval as group admin.' => 'Um ou mais usuários necessitam da sua aprovação como administrador de grupo.',
  'Only applicable when limited access for non-authenticated users is enabled. Only affects new users.' => 'Apenas aplicável quando o acesso limitado para usuários não-autenticados está habilitado. Afeta apenas novos usuários.',
  'Overview' => 'Visão Global',
  'Password' => 'Senha',
  'Pending approvals' => 'Aprovações pendentes',
  'Pending user approvals' => 'Aprovações de usuários pendentes',
  'People' => 'Pessoas',
  'Permanently delete' => 'Excluir permanentemente',
  'Permissions' => 'Permissões',
  'Prioritised User Group' => '',
  'Profile Permissions' => 'Permissões de perfil',
  'Profiles' => 'Perfis',
  'Protected' => 'Protegido',
  'Protected group can not be deleted!' => '',
  'Remove from group' => 'Remover do grupo',
  'Require group admin approval after registration' => 'Exigir aprovação do grupo de administração após o registro',
  'Resend invitation email' => 'Reenvie o email de convite',
  'Save' => 'Salvar',
  'Search by name, email or id.' => 'Pesquise por nome, email ou id.',
  'Select Groups' => 'Selecionar Grupos',
  'Select a prioritised group whose members are displayed before all others when the sorting option \'Default\' is selected. The users within the group and the users outside the group are additionally sorted by their last login.' => '',
  'Select which user information should be displayed in the \'People\' overview. You can select any profile fields, even those you have created individually. ' => '',
  'Send & decline' => 'Enviar e recusar',
  'Send & save' => 'Enviar e salvar',
  'Send invitation email' => 'Enviar email de convite',
  'Send invitation email again?' => 'Enviar email de convite novamente?',
  'Send invite' => 'Enviar convite',
  'Send notifications to users when added to or removed from the group.' => 'Envie notificações aos usuários quando forem adicionados ou removidos do grupo.',
  'Settings' => 'Configurações',
  'Show group selection at registration' => 'Mostrar seleção de grupo no registro',
  'Subject' => 'Assunto',
  'The Space memberships of all group members will be updated. This may take up to several minutes.' => 'As associações ao Espaço de todos os membros do grupo serão atualizadas. Isso pode levar vários minutos.',
  'The following list contains all pending sign-ups and invites.' => 'A lista a seguir contem todos os cadastros e convites pendentes.',
  'The following list contains all registered users awaiting an approval.' => 'A lista a seguir contém todos os usuários registrados que aguardam uma aprovação.',
  'The selected invitations have been successfully deleted!' => 'Os convites selecionados foram excluídos com sucesso!',
  'The user is the owner of these spaces:' => 'O usuário é o proprietário desses espaços:',
  'This option allows you to determine whether users may set individual permissions for their own profiles.' => 'Esta opção permite determinar se os usuários podem definir permissões individuais para seus próprios perfis.',
  'This overview contains a list of each registered user with actions to view, edit and delete users.' => 'Esta visão geral contém uma lista de cada usuário registrado com ações para visualizar, editar e excluir usuários.',
  'This user owns no spaces.' => 'Este usuário não possui espaços.',
  'Unapproved' => 'Não aprovado',
  'User deletion process queued.' => 'Processo de exclusão do usuário enfileirado.',
  'User is already a member of this group.' => 'Usuário já é um membro desse grupo.',
  'User not found!' => 'Usuário não encontrado!',
  'Users can be assigned to different groups (e.g. teams, departments etc.) with specific standard spaces, group managers and permissions.' => 'Os usuários podem pertencer a diferentes grupos (p. ex. equipes, departamentos etc.) com normas específicas de espaço, gerentes de grupo e permissões.',
  'Using this option any contributions (e.g. contents, comments or likes) of this user will be irrevocably deleted.' => 'Usando essa opção, quaisquer contribuições (por exemplo, conteúdo, comentários ou curtidas) desse usuário serão irrevogavelmente excluídas.',
  'View profile' => 'Ver perfil',
  'Visible for members only' => 'Visível apenas para membros',
  'Visible for members+guests' => 'Vísivel para membros e visitantes',
  'Will be used as a filter in \'People\'.' => '',
  'Yes' => 'Sim',
  'You can only delete empty categories!' => 'Você só pode apagar categorias vazias!',
  'You cannot delete yourself!' => 'Você não pode se deletar!',
  'never' => 'nunca',
);
